﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Windows.Threading;
using System.Diagnostics;

namespace PseudoScope
{
	/// <summary>
	/// Interaction logic for MainWindow.xaml
	/// </summary>
	public partial class MainWindow : Window
	{
		#region Fields

		private const long MAXTICK = 100;
		private const int TIMEOUT = 50;
		private DispatcherTimer timer;
		private Stopwatch stopWatch = new Stopwatch();

		#endregion

		#region Construction / Initialization / Dispose

		public MainWindow()
		{
			InitializeComponent();
			InitializeTimer();
		}

		private void InitializeTimer()
		{
			this.timer = new DispatcherTimer();
			this.timer.Interval = TimeSpan.FromMilliseconds(1);
			this.timer.Tick += new EventHandler(OnTimerTick);

			this.timer.IsEnabled = true;

			this.textBlockTime.Visibility = System.Windows.Visibility.Hidden;
			timerTick = 0;
			tst = TIMEOUT;
			this.rectangle.Fill = Brushes.YellowGreen;
			this.stopWatch.Reset();
			this.stopWatch.Start();
		}

		#endregion

		#region Eventhandler


		static long tst = TIMEOUT;
		static long timerTick = 0;
		static bool[] mouseButtonDownData = new bool[MAXTICK];

		static bool isMouseButtonDown = false;
		static bool oldMouseButtonDown = false;

		void OnTimerTick(object sender, EventArgs e)
		{
			if (this.stopWatch.ElapsedMilliseconds >= tst)
			{
				mouseButtonDownData[timerTick] = isMouseButtonDown = Mouse.LeftButton == MouseButtonState.Pressed;
				timerTick++;
				//Debug.WriteLine(timerTick);
				tst += TIMEOUT;

				if (isMouseButtonDown != oldMouseButtonDown)
				{
					this.rectangle.Fill = isMouseButtonDown ? Brushes.Red : Brushes.YellowGreen;
					oldMouseButtonDown = isMouseButtonDown;
				}

				if (timerTick >= MAXTICK)
				{
					this.timer.IsEnabled = false;
					this.rectangle.Fill = Brushes.PowderBlue;
					this.stopWatch.Stop();
					this.textBlockTime.Text = this.stopWatch.Elapsed.ToString();
					this.textBlockTime.Visibility = System.Windows.Visibility.Visible;

					this.scope.FillTrigger(mouseButtonDownData);
					this.scope.Visibility = System.Windows.Visibility.Visible;

				}
			
			}

		}

		#endregion

		private void Window_KeyDown(object sender, KeyEventArgs e)
		{
			if (e.Key == Key.F5)
			{
				this.scope.Visibility = System.Windows.Visibility.Hidden;

				InitializeTimer();
			}
		}
	}
}
